@@ -3,7 +3,6 @@ try:
 except:
     raise ImportError("You need to install tornado for this to work (pip install tornado==4.0.2)")
 from cantrips.protocol.messaging import MessageProcessor
-from future.utils import istext
 
 
 class MessageHandler(WebSocketHandler, MessageProcessor):
@@ -36,4 +35,4 @@ class MessageHandler(WebSocketHandler, MessageProcessor):
         self._conn_made()
 
     def on_message(self, message):
-        self._conn_message(message, not istext(message))
\ No newline at end of file
+        self._conn_message(message)
\ No newline at end of file
